# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/tarot/bot.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15tarot/tarot/bot.proto\x12\x05tarot\"+\n\rMessageAction\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\r\n\x05title\x18\x01 \x01(\t\"c\n\x12SendMessageRequest\x12\x0f\n\x07message\x18\x01 \x01(\t\x12%\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32\x14.tarot.MessageAction\x12\x15\n\rrecipient_ids\x18\x03 \x03(\x03\"L\n\x11MessageSentStatus\x12\x14\n\x0crecipient_id\x18\x01 \x01(\x03\x12!\n\x06status\x18\x02 \x01(\x0e\x32\x11.tarot.SentStatus\"A\n\x13SendMessageResponse\x12*\n\x08statuses\x18\x01 \x03(\x0b\x32\x18.tarot.MessageSentStatus*t\n\nSentStatus\x12\x1b\n\x17SENT_STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10SENT_STATUS_SENT\x10\x01\x12\x15\n\x11SENT_STATUS_ERROR\x10\x02\x12\x1c\n\x18SENT_STATUS_USER_BLOCKED\x10\x03\x32T\n\nBotManager\x12\x46\n\x0bSendMessage\x12\x19.tarot.SendMessageRequest\x1a\x1a.tarot.SendMessageResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.tarot.bot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SENTSTATUS']._serialized_start=323
  _globals['_SENTSTATUS']._serialized_end=439
  _globals['_MESSAGEACTION']._serialized_start=32
  _globals['_MESSAGEACTION']._serialized_end=75
  _globals['_SENDMESSAGEREQUEST']._serialized_start=77
  _globals['_SENDMESSAGEREQUEST']._serialized_end=176
  _globals['_MESSAGESENTSTATUS']._serialized_start=178
  _globals['_MESSAGESENTSTATUS']._serialized_end=254
  _globals['_SENDMESSAGERESPONSE']._serialized_start=256
  _globals['_SENDMESSAGERESPONSE']._serialized_end=321
  _globals['_BOTMANAGER']._serialized_start=441
  _globals['_BOTMANAGER']._serialized_end=525
# @@protoc_insertion_point(module_scope)
